@@ -3,18 +3,21 @@ import asyncio
 import logging
 import sys
 from argparse import ArgumentParser
-from typing import List, ValuesView
+from typing import (
+    List,
+    ValuesView,
+)
 
+from pyvelop.const import _PACKAGE_VERSION
 from pyvelop.device import Device
-from pyvelop.mesh import (
-    Mesh,
+from pyvelop.exceptions import (
     MeshBadResponse,
     MeshNodeNotPrimary,
     MeshInvalidCredentials,
     MeshTimeoutError,
 )
+from pyvelop.mesh import Mesh
 from pyvelop.node import Node
-from pyvelop.const import _PACKAGE_VERSION
 
 
 def _setup_args(parser: ArgumentParser) -> None:
@@ -98,6 +101,7 @@ async def main() -> None:
             logging.getLogger("pyvelop.mesh").setLevel(logging.DEBUG)
             logging.getLogger("pyvelop.mesh.verbose").setLevel(logging.INFO)
             if args.verbose > 2:
+                logging.getLogger("pyvelop.jnap").setLevel(logging.DEBUG)
                 logging.getLogger("pyvelop.mesh.verbose").setLevel(logging.DEBUG)
     # endregion
 
@@ -120,6 +124,16 @@ async def main() -> None:
             _LOGGER.error("Timeout connecting to %s", args.primary_node)
         else:
             if args.target == "mesh":
+                # region #-- general details --#
+                if all_args:
+                    _LOGGER.debug("Processing general details")
+                    section = "Overview"
+                    section += f"\n{'-' * len(section)}\n"
+                    section += f"Update Mode: {_mesh.update_type}\n"
+                    section += f"Speedtest Status: {_mesh.speedtest_status or 'N/A'}"
+                    sections.append(section)
+                # endregion
+
                 # region #-- get the node names --#
                 if args.get_nodes or all_args:
                     _LOGGER.debug("Preparing node names")
@@ -171,7 +185,7 @@ async def main() -> None:
                     sections.append(section)
                 # endregion
 
-                # region #-- get the storage server settings --#
+                # region #-- get available storage --#
                 if args.get_available_storage or all_args:
                     _LOGGER.debug("Preparing available storage")
                     section = "Available Storage"
@@ -318,7 +332,13 @@ async def main() -> None:
                             section = "Overview"
                             section += f"\n{'-' * len(section)}\n"
                             section += f"Device ID: {_d.unique_id}\n"\
-                                       f"Name: {_d.name}\n"\
+                                       f"Last Queried: {_d.results_time}\n"\
+                                       f"Name: {_d.name}\n" \
+                                       f"Manufacturer: {_d.manufacturer}\n" \
+                                       f"Model: {_d.model}\n" \
+                                       f"Description: {_d.description}\n" \
+                                       f"Operating System: {_d.operating_system}\n" \
+                                       f"Serial #: {_d.serial}\n" \
                                        f"Online: {_d.status}\n"\
                                        f"IP: {','.join(connected_adapters)}\n"\
                                        f"Parent: {_d.parent_name}\n"\
